@@ -15,6 +15,7 @@
 #' @param mysql_port Port on which the MySQL server listens for connections
 #' @param mysql_dbname Name of the database on the MySQL server which is used by
 #' `LimeSurvey`
+#' @param mysql_table_prefix Prefix for all table names, e.g. "lime_"
 #' @param mysql_username Username for the MySQL server
 #' @param mysql_password Password for the MySQL server
 #'
@@ -34,6 +35,7 @@
 #'   mysql_host = '127.0.0.1',
 #'   mysql_port = 3306,
 #'   mysql_dbname = 'limesurvey',
+#'   mysql_table_prefix = '',
 #'   mysql_username = 'lime',
 #'   mysql_password = '1234lime'
 #' )
@@ -48,6 +50,7 @@ connect_to_limesurvey <- function(
     mysql_host,
     mysql_port,
     mysql_dbname,
+    mysql_table_prefix,
     mysql_username,
     mysql_password
 ) {
@@ -55,6 +58,7 @@ connect_to_limesurvey <- function(
   ipanema_cache$mysql_username <- mysql_username
   ipanema_cache$mysql_password <- mysql_password
   ipanema_cache$mysql_dbname <- mysql_dbname
+  ipanema_cache$mysql_table_prefix <- mysql_table_prefix
   ipanema_cache$mysql_host <- mysql_host
   ipanema_cache$mysql_port <- mysql_port
 
