@@ -27,6 +27,7 @@
 #'   mysql_host = '127.0.0.1',
 #'   mysql_port = 3306,
 #'   mysql_dbname = 'limesurvey',
+#'   mysql_table_prefix = '',
 #'   mysql_username = 'lime',
 #'   mysql_password = '1234lime'
 #' )
@@ -76,7 +77,7 @@ get_answer_options <- function(question_code) {
       conn,
       paste0(
         'SELECT qid ',
-        'FROM questions ',
+        'FROM ', ipanema_cache$mysql_table_prefix, 'questions ',
         "WHERE type = 'F' AND ",
         'title = ', "'", group, "'"
       )
@@ -86,7 +87,7 @@ get_answer_options <- function(question_code) {
       conn,
       paste0(
         'SELECT code, answer ',
-        'FROM answers ',
+        'FROM ', ipanema_cache$mysql_table_prefix, 'answers ',
         'WHERE qid = ', parent_qid
       )
     )
@@ -96,7 +97,7 @@ get_answer_options <- function(question_code) {
       conn,
       paste0(
         'SELECT qid ',
-        'FROM questions ',
+        'FROM ', ipanema_cache$mysql_table_prefix, 'questions ',
         "WHERE type <> 'F' AND ",
         'title = ', "'", question_code, "'"
       )
@@ -106,7 +107,7 @@ get_answer_options <- function(question_code) {
       conn,
       paste0(
         'SELECT code, answer ',
-        'FROM answers ',
+        'FROM ', ipanema_cache$mysql_table_prefix, 'answers ',
         'WHERE qid = ', question_qid
       )
     )
