@@ -25,6 +25,7 @@
 #'   mysql_host = '127.0.0.1',
 #'   mysql_port = 3306,
 #'   mysql_dbname = 'limesurvey',
+#'   mysql_table_prefix = '',
 #'   mysql_username = 'lime',
 #'   mysql_password = '1234lime'
 #' )
@@ -74,7 +75,7 @@ get_question_text <- function(question_code) {
       conn,
       paste0(
         'SELECT qid ',
-        'FROM limesurvey.questions ',
+        'FROM ', ipanema_cache$mysql_table_prefix, 'questions ',
         "WHERE type = 'F' AND ",
         'title = ', "'", group, "'"
       )
@@ -85,7 +86,7 @@ get_question_text <- function(question_code) {
       conn,
       paste0(
         'SELECT question ',
-        'FROM limesurvey.questions ',
+        'FROM ', ipanema_cache$mysql_table_prefix, 'questions ',
         "WHERE type <> 'F' AND ",
         "title = '", question, "' AND ",
         "parent_qid = ", parent_qid
@@ -97,7 +98,7 @@ get_question_text <- function(question_code) {
       conn,
       paste0(
         'SELECT question ',
-        'FROM limesurvey.questions ',
+        'FROM ', ipanema_cache$mysql_table_prefix, 'questions ',
         "WHERE title = '", question_code, "' AND ",
         "parent_qid = 0"
       )
